DebouncedInputEvent

Enum DebouncedInputEvent 

pub enum DebouncedInputEvent {
    Low,
    High,
    Rise,
    Fall,
}
The event result of update DebouncedInput.

Variants



Low

 Stable low state, the input is inactive.



High

Stable high state, the input is active.



Rise

Rise event, the input is rised from inactive to active state.



Fall

Fall event, the input is rised from active to inactive state.